import Vue from 'vue'
import Vuex from 'vuex'
import { normalCallPost } from './assets/utils';

Vue.use(Vuex)

let userData = {};
let currentParentName = ''
let headBar = []

try {
  userData = JSON.parse(window.sessionStorage.userData || '{}');
  currentParentName = window.sessionStorage.currentParentName || ''
  headBar = JSON.parse(window.sessionStorage.headBar || '{}')
} catch (error) {
  console.log('未从session中获取到userData')
  console.log('未从session中获取到currentParentName')
}

function convertTreeToList(root, array) {
  if(!root || !root.length) return array;
  root.forEach(item=>{
    let data = JSON.parse(JSON.stringify(item));
    const url = data.url ? data.url : (item.childList[0] ? (item.childList[0].url || '') : '');
    delete data.childList;
    array.push({
      name: data.name,
      path: data.url,
      id: data.id,
      parentId: data.parentId,
      icon: data.imgPath,
    });
    if(item.childList){
      convertTreeToList(item.childList, array);
    }
  })
  return array;
}

function isPc() {
  var userAgentInfo = navigator.userAgent;  
  var Agents = new Array("Android", "iPhone", "SymbianOS", "Windows Phone", "iPad", "iPod");  
  var flag = true;  
  for (var v = 0; v < Agents.length; v++) {  
    if (userAgentInfo.indexOf(Agents[v]) > 0) { flag = false; break; }  
  }  
  return flag;
}

export default new Vuex.Store({
  state: {
    isLogin: false,
    isMobile: !isPc(),
    userData,//用户数据
    group: '',
    headBar,
    currentParentName//当前选择菜单
  },
  // 同步存储数据
  mutations: {
    setUserData(state, data) {
      data.flat = convertTreeToList(data.barList, []);
      state.userData = Object.assign({}, state.userData, data);
      state.isLogin = true;
      window.sessionStorage.userData = JSON.stringify(data);
      window.sessionStorage.token = data.token;
    },
    setHeadBar(state,data){
      state.headBar = data
      window.sessionStorage.headBar = JSON.stringify(data)
    },
    logout(state) {
      state.userData = {};
      state.isLogin = false;
      window.sessionStorage.userData = '';
      window.sessionStorage.token = '';
    },
    setGroup(state, data) {
      state.group = data;
    },
    setCurrentParentName(state,data){
      state.currentParentName = data
      window.sessionStorage.currentParentName = data
    }
  },
  // 异步任务
  actions: {
    login({commit}) {
      normalCallPost('/login/index').then(({data})=>{
        commit('setUserData', data)
      }).catch(error=>{

      })
    },
    logout({commit}) {
      normalCallPost('/login/logout').then(data=>{}).catch(error=>{}).then(()=>{
        commit('logout')
      })
    }
  }
})
